﻿// Copyright (c) Brock Allen & Dominick Baier. All rights reserved.
// Licensed under the Apache License, Version 2.0. See LICENSE in the project root for license information.


using System;
using System.Linq;
using System.Threading.Tasks;
using HaBook.IES.IdentityServer.AzureTableStorage.Mappers;
using HaBook.IES.IdentityServer.AzureTableStorage.Options;
using IdentityServer4.Models;
using IdentityServer4.Stores;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Options;
using Microsoft.WindowsAzure.Storage;
using Microsoft.WindowsAzure.Storage.Table;

namespace HaBook.IES.IdentityServer.AzureTableStorage.Stores
{
    /// <summary>
    /// Implementation of IClientStore thats uses EF.
    /// </summary>
    /// <seealso cref="IdentityServer4.Stores.IClientStore" />
    public class ClientStore : IClientStore
    {
        //private readonly IConfigurationDbContext _context;
        private readonly ILogger<ClientStore> _logger;
        private readonly string _connectionString;
        private CloudTable _cloudTable;
        
        /// <summary>
        /// Initializes a new instance of the <see cref="ClientStore"/> class.
        /// </summary>
        /// <param name="context">The context.</param>
        /// <param name="logger">The logger.</param>
        /// <exception cref="ArgumentNullException">context</exception>
        public ClientStore(
           // IConfigurationDbContext context,
           IOptions<DatabaseOptions> optionsAccessor,
            ILogger<ClientStore> logger)
        {
            // _context = context ?? throw new ArgumentNullException(nameof(context));
            _connectionString = optionsAccessor.Value.ConnectionString;
            _logger = logger;
        }
        async Task<CloudTable> InitTable()
        {
            if (_cloudTable != null) return _cloudTable;

            var storageAccount = CloudStorageAccount.Parse(_connectionString);
            var tableClient = storageAccount.CreateCloudTableClient();
            _cloudTable = tableClient.GetTableReference("IdentityServer4ClientStore");
            await _cloudTable.CreateIfNotExistsAsync();

            return _cloudTable;
        }
        /// <summary>
        /// Finds a client by id
        /// </summary>
        /// <param name="clientId">The client id</param>
        /// <returns>
        /// The client
        /// </returns>
        public async Task<Client> FindClientByIdAsync(string clientId)
        {
            // TODO处理业务逻辑
            var table = await InitTable();

            Entities.Client entity = null;
            var query = new TableQuery<Entities.Client>().Where(TableQuery.GenerateFilterCondition("ClientId", QueryComparisons.Equal, clientId));
            TableContinuationToken continuationToken = null;
            do
            {
                var result = await table.ExecuteQuerySegmentedAsync(query, continuationToken);
                if (result.Results.Count > 0)
                {
                    entity = result.Results[0];
                    break;
                }
                continuationToken = result.ContinuationToken;
            } while (continuationToken != null);

            //处理子表业务
            // TODO实体业务逻辑
            //_logger.LogDebug("{clientId} found in database: {IdentityServer4ClientStore}", clientId, entity != null);
            //var client = _context.Clients
            //    .Include(x => x.AllowedGrantTypes)
            //    .Include(x => x.RedirectUris)
            //    .Include(x => x.PostLogoutRedirectUris)
            //    .Include(x => x.AllowedScopes)
            //    .Include(x => x.ClientSecrets)
            //    .Include(x => x.Claims)
            //    .Include(x => x.IdentityProviderRestrictions)
            //    .Include(x => x.AllowedCorsOrigins)
            //    .Include(x => x.Properties)
            //    .AsNoTracking()
            //    .FirstOrDefault(x => x.ClientId == clientId);
            var model = entity?.ToModel();
            _logger.LogDebug("{clientId} found in database: {clientIdFound}", clientId, model != null);
            return await Task.FromResult(model);
        }
    }
}