﻿using System;
using System.Reflection;
using HaBook.IES.IdentityServer.EFCore.Contexts;
using HaBook.IES.IdentityServer.EFCore.Data;
using IdentityServer4.EntityFramework.Services;
using IdentityServer4.EntityFramework.Stores;
using IdentityServer4.Test;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Pomelo.EntityFrameworkCore.MySql.Infrastructure;
using Powel.AzureTableStorage.IdentityServer4.Options;

namespace HaBook.IES.IdentityServer.EFCore
{
    public class Startup
    {
        public Startup(IConfiguration configuration)
        {
            Configuration = configuration;
        }

        public DatabaseOptions Value => new DatabaseOptions
        {
            ConnectionString = "DefaultEndpointsProtocol=https;AccountName=teammodelstorage;AccountKey=Yq7D4dE6cFuer2d2UZIccTA/i0c3sJ/6ITc8tNOyW+K5f+/lWw9GCos3Mxhj47PyWQgDL8YbVD63B9XcGtrMxQ==;EndpointSuffix=core.chinacloudapi.cn"
        };

        public IConfiguration Configuration { get; }

        // This method gets called by the runtime. Use this method to add services to the container.
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddMvc().SetCompatibilityVersion(CompatibilityVersion.Version_2_1);
            services.Configure<CookiePolicyOptions>(options =>
            {
                // This lambda determines whether user consent for non-essential cookies is needed for a given request.
                options.CheckConsentNeeded = context => true;
                options.MinimumSameSitePolicy = SameSiteMode.None;
            });
            var migrationsAssembly = typeof(Startup).GetTypeInfo().Assembly.GetName().Name;
            // other service configurations go here

          //  const string connectionString = "server=127.0.0.1;uid=root;port=3306;pwd=hhb353897079;database=habook-identity-server;SslMode=None;";
            const string connectionString = "server=127.0.0.1;uid=root;port=3306;pwd=habook;database=habook-identity-server;SslMode=None;";
            //string connectionString = Configuration.GetConnectionString("HaBookIdentityServerConnection");
            //const string connectionString = "server=127.0.0.1;uid=root;pwd=habook;database=habook-identity-server;";
            services.AddDbContextPool<DbContext>( // replace "YourDbContext" with the class name of your DbContext
                                                    //server=127.0.0.1;uid=root;port=3306;pwd=habook;database=habook-sso;SslMode=None;
                //options => options.UseMySql("Server=127.0.0.1;Database=habook-sso;User=root;Password=habook;",
                 options => options.UseMySql(connectionString,
                    // replace with your Connection String
                    mysqlOptions =>
                    {
                        mysqlOptions
                        .ServerVersion(new Version(5, 7, 23), ServerType.MySql)
                        .UnicodeCharSet(CharSet.Utf8mb4).AnsiCharSet(CharSet.Latin1)
                        .CharSetBehavior(CharSetBehavior.AppendToAllColumns); // replace with your Server Version and Type
                    }
            ));
            services.AddIdentityServer(options =>
            {
                options.Events.RaiseErrorEvents = true;
                options.Events.RaiseInformationEvents = true;
                options.Events.RaiseFailureEvents = true;
                options.Events.RaiseSuccessEvents = true;
            }).AddDeveloperSigningCredential().AddConfigurationStore(options =>
            {
                options.ConfigureDbContext = builder =>
                    builder.UseMySql(connectionString,
                        sql => sql.MigrationsAssembly(migrationsAssembly));
            }).AddOperationalStore(options =>
            {
                options.ConfigureDbContext = builder =>
                    builder.UseMySql(connectionString,
                        sql => sql.MigrationsAssembly(migrationsAssembly));
                options.EnableTokenCleanup = true;
                options.TokenCleanupInterval = 30;
                
              
            })
            .AddResourceOwnerValidator<ResourceOwnerPasswordValidator>()
            .AddProfileService<ProfileService>().AddRedisCaching(options => {
                options.RedisConnectionString = "192.168.8.241:26379";
                options.Db = 0;
                options.KeyPrefix = "habook:sso";

                //options.RedisConnectionString = "teammodel.redis.cache.chinacloudapi.cn:6380,password=9wcTVDiAWiAf0IF5NOjZBvYrZe9JlbEw1E3F1QFcNbo=,ssl=True,abortConnect=False";
                //options.Db = 1;
                //options.KeyPrefix = "habook:sso";
            })
            .AddClientStoreCache<ClientStore>()
            .AddResourceStoreCache<ResourceStore>()
            .AddCorsPolicyCache<CorsPolicyService>()
            .AddProfileServiceCache<ProfileService>().AddConfigurationStoreCache();

            
            //.AddInMemoryApiResources(ClientResource.GetApiResources())
            //.AddInMemoryClients(ClientResource.GetClients())
            //.AddDeveloperSigningCredential().AddTestUsers(Config.getu)
            //.AddTestUsers(InitialData.GetUsers());
            //.AddTestUsers(  TestUsers.Users);
            // .AddAspNetIdentity<HaBookUser>();
            //services.AddIdentityServer()
            //.AddDeveloperSigningCredential()
            //.AddInMemoryIdentityResources(InitialData.GetIdentityResources())
            //.AddInMemoryApiResources(InitialData.GetApiResources())
            //.AddInMemoryClients(InitialData.GetClients())
            //.AddResourceOwnerValidator<ResourceOwnerPasswordValidator>()
            //.AddProfileService<ProfileService>();
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IHostingEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }
            else
            {
                app.UseExceptionHandler("/Home/Error");
                app.UseHsts();
            }

            app.UseHttpsRedirection();
            app.UseStaticFiles();
            app.UseCookiePolicy();
            //启用IdentityServer
            app.UseIdentityServer();
            app.UseMvcWithDefaultRoute();
            app.UseMvc(routes =>
            {
                routes.MapRoute(
                    name: "default",
                    template: "{controller=Home}/{action=Index}/{id?}");
            });
        }
    }
}
